==> eiffelstudio-18.01.10.1424.tar: F_code/C10/co461.c <==
/*
 * Code for class CONF_ERROR_PARSE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co461.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_PARSE}.message */
EIF_REFERENCE F746_7543 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CONF_ERROR_PARSE}.file */
EIF_REFERENCE F746_7544 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {CONF_ERROR_PARSE}.text */
EIF_REFERENCE F746_7548 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Result);
	RTLR(3,Current);
	RTLR(4,loc1);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1113, 0x01).id, 1113, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr2 = RTMS32_EX_H("P\000\000\000a\000\000\000r\000\000\000s\000\000\000e\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",11,62499698);
	F1109_9457(RTCW(tr1), tr2);
	Result = (EIF_REFERENCE) tr1;
	switch (*(EIF_INTEGER_32 *)(Current + O6653[dtype-745])) {
		case 1L:
			tr1 = RTMS32_EX_H(" \000\000\000(\000\000\000X\000\000\000M\000\000\000L\000\000\000 \000\000\000s\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000)\000\000\000 \000\000\000",14,1829568544);
			F1114_9673(RTCW(Result), tr1);
			break;
		case 2L:
			tr1 = RTMS32_EX_H(" \000\000\000(\000\000\000A\000\000\000C\000\000\000E\000\000\000 \000\000\000s\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000)\000\000\000 \000\000\000",14,1394758688);
			F1114_9673(RTCW(Result), tr1);
			break;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000",4,543780384);
		tr1 = F1114_9675(tr1, loc1);
		tr2 = RTMS32_EX_H(" \000\000\000(\000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",7,774604064);
		tr1 = F1114_9675(RTCW(tr1), tr2);
		F1114_9673(RTCW(Result), tr1);
		F1114_9677(RTCW(Result), *(EIF_INTEGER_32 *)(Current + O6651[dtype-745]));
		tr1 = RTMS32_EX_H(",\000\000\000 \000\000\000c\000\000\000o\000\000\000l\000\000\000u\000\000\000m\000\000\000n\000\000\000 \000\000\000",9,933104928);
		F1114_9673(RTCW(Result), tr1);
		F1114_9677(RTCW(Result), *(EIF_INTEGER_32 *)(Current + O6652[dtype-745]));
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ')';
		F1114_9687(RTCW(Result), tw1);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTMS32_EX_H(":\000\000\000 \000\000\000",2,14880);
		F1114_9673(RTCW(Result), tr1);
		F1114_9672(RTCW(Result), loc2);
	}
	RTLE;
	return Result;
}

/* {CONF_ERROR_PARSE}.set_xml_parse_mode */
void F746_7550 (EIF_REFERENCE Current)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current + O6653[Dtype(Current)-745]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
}

/* {CONF_ERROR_PARSE}.set_position */
void F746_7552 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current + O6651[dtype-745]) = (EIF_INTEGER_32) arg2;
	*(EIF_INTEGER_32 *)(Current + O6652[dtype-745]) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {CONF_ERROR_PARSE}.set_message */
void F746_7553 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
}

void EIF_Minit461 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C10/co461.c <==
/*
 * Code for class CONF_ERROR_PARSE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co461.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_PARSE}.text */
EIF_REFERENCE F547_6973 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,tr1);
	RTLR(1,Result);
	RTLR(2,Current);
	RTLR(3,loc1);
	RTLR(4,tr2);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	Result = RTLNS(eif_new_type(1129, 0x01).id, 1129, _OBJSIZ_1_1_0_3_0_0_0_0_);
	tr1 = RTMS32_EX_H("P\000\000\000a\000\000\000r\000\000\000s\000\000\000e\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",11,62499698);
	F1128_9744(RTCW(Result), tr1);
	switch (*(EIF_INTEGER_32 *)(Current + O6279[dtype-546])) {
		case 1L:
			tr1 = RTMS32_EX_H(" \000\000\000(\000\000\000X\000\000\000M\000\000\000L\000\000\000 \000\000\000s\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000)\000\000\000 \000\000\000",14,1829568544);
			F1130_9855(RTCW(Result), tr1);
			break;
		case 2L:
			tr1 = RTMS32_EX_H(" \000\000\000(\000\000\000A\000\000\000C\000\000\000E\000\000\000 \000\000\000s\000\000\000y\000\000\000n\000\000\000t\000\000\000a\000\000\000x\000\000\000)\000\000\000 \000\000\000",14,1394758688);
			F1130_9855(RTCW(Result), tr1);
			break;
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000",4,543780384);
		tr1 = F1130_9857(tr1, loc1);
		tr2 = RTMS32_EX_H(" \000\000\000(\000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",7,774604064);
		tr1 = F1130_9857(RTCW(tr1), tr2);
		F1130_9855(RTCW(Result), tr1);
		F1130_9859(RTCW(Result), *(EIF_INTEGER_32 *)(Current + O6277[dtype-546]));
		tr1 = RTMS32_EX_H(",\000\000\000 \000\000\000c\000\000\000o\000\000\000l\000\000\000u\000\000\000m\000\000\000n\000\000\000 \000\000\000",9,933104928);
		F1130_9855(RTCW(Result), tr1);
		F1130_9859(RTCW(Result), *(EIF_INTEGER_32 *)(Current + O6278[dtype-546]));
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ')';
		F1130_9869(RTCW(Result), tw1);
	}
	tr1 = *(EIF_REFERENCE *)(Current);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTMS32_EX_H(":\000\000\000 \000\000\000",2,14880);
		F1130_9855(RTCW(Result), tr1);
		F1130_9854(RTCW(Result), loc2);
	}
	RTLE;
	return Result;
}

/* {CONF_ERROR_PARSE}.set_xml_parse_mode */
void F547_6975 (EIF_REFERENCE Current)
{
	GTCX
	
	
	*(EIF_INTEGER_32 *)(Current + O6279[Dtype(Current)-546]) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
}

/* {CONF_ERROR_PARSE}.set_position */
void F547_6977 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current + O6277[dtype-546]) = (EIF_INTEGER_32) arg2;
	*(EIF_INTEGER_32 *)(Current + O6278[dtype-546]) = (EIF_INTEGER_32) arg3;
	RTLE;
}

/* {CONF_ERROR_PARSE}.set_message */
void F547_6978 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
}

void EIF_Minit461 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
